@@ -62,7 +62,7 @@ class Task:
         return len(self.subtasks)
 
     def getTaskInfo(self): 
-        return f"Aufgabe {self.task}, {self.points} Punkte, {self.getTaskNo()} Teilaufgaben"
+        return f"Aufgabe {self.task}, {self.getPoints()} Punkte, {self.getTaskNo()} Teilaufgaben"
         
     def getPoints(self):
         x = 0
